@@ -11,14 +11,9 @@ Copyright © Semantyk 2020. All rights reserved.\
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
 """
 
-from . import chart
-from . import graph
-from . import network
-from . import timeline
-from . import venn_diagram
-
+from . import chart, graph, network, timeline, venn_diagram
 from .chart import *
 from .graph import *
 from .network import *
 from .timeline import *
-from .venn_diagram import *
\ No newline at end of file
+from .venn_diagram import *
